summaryrefslogtreecommitdiff
path: root/org.genivi.commonapi.core.ui/src/org/genivi/commonapi/core/ui/handler/GenerationCommand.java
diff options
context:
space:
mode:
Diffstat (limited to 'org.genivi.commonapi.core.ui/src/org/genivi/commonapi/core/ui/handler/GenerationCommand.java')
-rw-r--r--org.genivi.commonapi.core.ui/src/org/genivi/commonapi/core/ui/handler/GenerationCommand.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/org.genivi.commonapi.core.ui/src/org/genivi/commonapi/core/ui/handler/GenerationCommand.java b/org.genivi.commonapi.core.ui/src/org/genivi/commonapi/core/ui/handler/GenerationCommand.java
index 5bd5b38..a842602 100644
--- a/org.genivi.commonapi.core.ui/src/org/genivi/commonapi/core/ui/handler/GenerationCommand.java
+++ b/org.genivi.commonapi.core.ui/src/org/genivi/commonapi/core/ui/handler/GenerationCommand.java
@@ -316,7 +316,7 @@ public class GenerationCommand extends AbstractHandler {
System.err.println("Failed to get property for " + resource.getName());
}
// Set defaults in the case, where nothing was specified from the user.
if(outputFolderCommon == null) {
outputFolderCommon = store.getString(PreferenceConstants.P_OUTPUT_COMMON);
}
@@ -339,13 +339,13 @@ public class GenerationCommand extends AbstractHandler {
licenseHeader = store.getString(PreferenceConstants.P_LICENSE);
}
if(generateProxy == null) {
- generateProxy = "true";
+ generateProxy = store.getString(PreferenceConstants.P_GENERATEPROXY);
}
if(generatStub == null) {
- generatStub = "true";
+ generatStub = store.getString(PreferenceConstants.P_GENERATESTUB);
}
if(generatSkeleton == null) {
- generatSkeleton = "false";
+ generatSkeleton = store.getString(PreferenceConstants.P_GENERATESKELETON);
}
// finally, store the properties for the code generator
@@ -316,7 +316,7 @@ public class GenerationCommand extends AbstractHandler {
System.err.println("Failed to get property for " + resource.getName());
}
- // Set defaults in the case, where nothing was specified from the user.
+ // Set defaults from the preference store in the case, where the value was not specified in the properties.
if(outputFolderCommon == null) {
outputFolderCommon = store.getString(PreferenceConstants.P_OUTPUT_COMMON);